@@ -56,7 +56,7 @@ Clarion <- R6::R6Class("Clarion",
                            # return unique_id
                            # if no type return first feature
                            if (is.element("type", names(self$metadata))) {
-                             return(self$metadata[type == "unique_id"][["key"]])
+                             return(self$metadata[type == "unique_id"][["key"]][1])
                            } else {
                              return(self$metadata[level == "feature"][["key"]][1])
                            }
@@ -117,6 +117,8 @@ Clarion <- R6::R6Class("Clarion",
                            self$metadata <- metadata
                            self$data <- data
 
+                           if (validate) self$validate()
+
                            # coerce unique_id and name to character
                            if (self$get_id() == self$get_name()) {
                              cols <- self$get_id()
@@ -124,8 +126,6 @@ Clarion <- R6::R6Class("Clarion",
                              cols <- c(self$get_id(), self$get_name())
                            }
                            self$data[, (cols) := lapply(.SD, as.character), .SDcols = cols]
-
-                           if (validate) self$validate()
                          }
                        ),
                        private = list(
@@ -201,6 +201,10 @@ Clarion <- R6::R6Class("Clarion",
                              if (!is.element("unique_id", self$metadata[["type"]])) {
                                stop("Metadata: No unique_id defined in type! Please define a unique_id.")
                              }
+                             # case: multiple unique_ids
+                             if (sum(is.element(self$metadata[["type"]], "unique_id")) > 1) {
+                               warning("Metadata: Found multiple unique_ids! Only first will be used.")
+                             }
                              # case: type = array but no delimiter
                              if (is.element("array", self$metadata[["type"]]) && !is.element("delimiter", names(self$header))) {
                                stop("Found type=array but no delimiter! Columns with multi-value fields require delimiter (in header) and type=array (in metadata).")
